
XEP-0085: Chat State Notifications
==================================

.. module:: slixmpp.plugins.xep_0085

.. autoclass:: XEP_0085
    :members:
    :exclude-members: session_bind, plugin_init, plugin_end


Stanza elements
---------------

.. automodule:: slixmpp.plugins.xep_0085.stanza
    :members:
    :undoc-members:

